magneticalc.QCheckboxConfig.QCheckboxConfig

# ``magneticalc`.`QCheckboxConfig`.`QCheckboxConfig``

class documentation

`class QCheckboxConfig:`

Constructor: `QCheckboxConfig(gui)`

View In Hierarchy

QCheckboxConfig class.

Method | `__init__` | Initializes a manager for configuration bound checkbox actions.
Method | `add` | Creates a checkbox action. The checkbox state is bound to the project configuration.
Method | `changed` | Handles change of checkbox state.
Method | `reload` | Reloads the configuration bound checkboxes.
Instance Variable | `actions` | Undocumented
Instance Variable | `gui` | Undocumented

def __init__(self, gui: `GUI`):

Initializes a manager for configuration bound checkbox actions.

def add(self, label: `str`, key: `str`, on_changed: `Callable`) -> `QAction`:

Creates a checkbox action. The checkbox state is bound to the project configuration.

Parameters
label: `str` | Label
key: `str` | Configuration key
on_changed: `Callable` | Gets called when the checkbox state changed

Returns
`QAction` | Undocumented

def changed(self, key: `str`):

Handles change of checkbox state.

Parameters
key: `str` | Configuration key

def reload(self):

Reloads the configuration bound checkboxes.

Note: This doesn't block the change signals.

actions: `dict[str, dict]` =

Undocumented

gui =

Undocumented